#include "Stomach.h"

Stomach::Stomach()
{
    _belly.resize(13);
    _digestion_rate = 1;
    _empty_space = _belly.size();
    _base_weight = 50;
    _fat_weight = 0;
    _body_weight = _fat_weight + _base_weight;
    _food_weight = 0;
    _total_weight = _base_weight + _fat_weight + _food_weight;
}

void Stomach::_update_total_weight()
{
    _total_weight = _base_weight + _fat_weight + _food_weight;
    _body_weight = _fat_weight + _base_weight;
}

void Stomach::eat_food(Food food_to_eat)
{
    for (size_t i = 0; i < _belly.size(); i++)
    {
        if (_belly[i].food_id() == 0)
        {
            _belly[i] = food_to_eat;
            _food_weight += food_to_eat.weight();
            _update_total_weight();
            _empty_space--;
            return;
        }
    }
}

void Stomach::digest_food()
{
    if (_belly[0].food_id() == 0)
    {
        // the first item in belly is empty, therefore there is nothing to digest, so we just exit the function
        return;
    }

    for (size_t i = 0; i < _digestion_rate; i++)
    {
        _food_weight -= _belly[i].weight();
        _fat_weight += _belly[i].fat_value();
        _belly[i].reset();
        _empty_space++;
    }

    // moving all items in belly by _digestion_rate tiles forward (backward? bottom of the stomach? Towards where they will be digested)
    for (size_t i = _digestion_rate; i < _belly.size(); i++)
    {
        _belly[i - _digestion_rate] = _belly[i];
    }
    // but it leaves _digestion_rate elements at the very top of the stomach, so we reset them here
    int food_to_remove = _belly.size() - _digestion_rate;
    for (; food_to_remove < _belly.size(); food_to_remove++)
    {
        _belly[food_to_remove].reset();
    }

    _update_total_weight();
    
}

void Stomach::print_info()
{
    cout << "Size: " << _belly.size() << "\n"
         << "Digestion Rate: " << _digestion_rate << "\n"
         << "Empty space: " << _empty_space << "\n"
         << "Base weight: " << _base_weight << "\n"
         << "Fat weight: " << _fat_weight << "\n"
         << "Body weight (without food in stomach): " << _body_weight << "\n"
         << "Food weight: " << _food_weight << "\n"
         << "Total weight: " << _total_weight << "\n";
    cout << "Stomach contents:\n";
    for (size_t i = 0; i < _belly.size(); i++)
    {
        if (_belly[i].food_id() == 0)
        {
            break;
        }
        
        cout << _belly[i].name() << endl;
    }
    
}
